/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: ICommonClassMetadata.java 3224 2008-05-15 09:37:33Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.api;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.interfaces.ISharedMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.scan.api.metadata.IClassMetadata;

/**
 * The common interface for class metadata.
 * @param <C> the common interface for class metadata
 * @param <M> the common interface for method metadata
 * @param <F> the common interface for field metadata
 * @author Gael Lalire
 */
public interface ICommonClassMetadata<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends ISharedMetadata, IClassMetadata<C, M, F> {

    /**
     * @return jEjbEJBs list representing &#64;{@link javax.ejb.EJBs}
     *         annotation.
     */
    List<IJEjbEJB> getJEjbEJBs();

    /**
     * Set JEjbEJBs object.
     * @param jEjbEJBs list representing javax.ejb.EJBs annotation.
     */
    void setJEjbEJBs(final List<IJEjbEJB> jEjbEJBs);

    /**
     * @return JAnnotationResources list representing &#64;{@link javax.annotation.Resources} annotation.
     */
    List<IJAnnotationResource> getJAnnotationResources();

    /**
     * Sets JAnnotationResources object.
     * @param jAnnotationResources list representing javax.annotation.Resources annotation.
     */
    void setJAnnotationResources(final List<IJAnnotationResource> jAnnotationResources);

    /**
     * @return javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *         annotation.
     */
    List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts();

    /**
     * Sets JavaxPersistencePersistenceContexts object.
     * @param javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *        annotation.
     */
    void setJavaxPersistencePersistenceContexts(final List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts);

    /**
     * @return javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits();

    /**
     * Sets setJavaxPersistencePersistenceUnits object.
     * @param javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    void setJavaxPersistencePersistenceUnits(final List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits);

}
